<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://eurofaktura.com
 * @since             1.0.0
 * @package           eurofaktura
 *
 * @wordpress-plugin
 * Plugin Name:       Eurofaktura
 * Description:       Connect WooCommerce to Eurofaktura (e-racuni) ERP and handle invoincing actions directly from WooCommerce
 * Version:           1.1.5
 * Author:            Eurofaktura
 * Author URI: 		  https://eurofaktura.com	
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       eurofaktura
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if (!defined('ABSPATH')) exit;

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define('EUROFAKTURA_VERSION', '1.1.5');
define('EUROFAKTURA_TITLE', 'Eurofaktura');

if (!function_exists('is_plugin_active')) {
	include_once(ABSPATH . '/wp-admin/includes/plugin.php');
}

/**
 * Check for the existence of WooCommerce and any other requirements
 */
function eurofaktura_check_requirements()
{
	$check_requirements_notice_key = 'requirements';
	if (is_plugin_active('woocommerce/woocommerce.php')) {
		Eurofaktura_admin_notices::instance()->remove_admin_notice($check_requirements_notice_key);
		return true;
	} else {
		/* translators: 1. Name of the product*/
		$message = sprintf(__('%1$s requires WooCommerce to be installed and active.', 'eurofaktura'), EUROFAKTURA_TITLE);
		Eurofaktura_admin_notices::instance()->add_admin_notice($message, $check_requirements_notice_key, 'error', true, false);
		return false;
	}
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-eurofaktura-activator.php
 */
function eurofaktura_activate()
{
	require_once plugin_dir_path(__FILE__) . 'includes/class-eurofaktura-activator.php';
	Eurofaktura_activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-eurofaktura-deactivator.php
 */
function eurofaktura_deactivate()
{
	require_once plugin_dir_path(__FILE__) . 'includes/class-eurofaktura-deactivator.php';
	Eurofaktura_deactivator::deactivate();
}

register_activation_hook(__FILE__, 'eurofaktura_activate');
register_deactivation_hook(__FILE__, 'eurofaktura_deactivate');

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path(__FILE__) . 'includes/class-eurofaktura.php';
require_once plugin_dir_path(__FILE__) . 'includes/class-eurofaktura-admin-notices.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function eurofaktura_run()
{
	if (eurofaktura_check_requirements()) {
		$plugin = new Eurofaktura();
		$plugin->run();
	}
}

eurofaktura_run();
