<?php

// If this file is called directly, abort.
if (!defined('ABSPATH')) exit;

/**
 * @since      1.0.0
 *
 * @package    eurofaktura
 * @subpackage eurofaktura/includes/admin/
 */

class Eurofaktura_admin
{
	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{
		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{
		wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/eurofaktura-admin.css', array(), $this->version, 'all');
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{
		wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/eurofaktura-admin.js', array('jquery'), $this->version, false);

		wp_localize_script(
			$this->plugin_name,
			'admin_vars',
			array(
				'close' => __('Close', 'eurofaktura'),
				'nonce' => wp_create_nonce(),
				'plugins_url' => plugins_url(),
			)
		);
	}

	/**
	 * Load dependencies for additional WooCommerce settings
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	public function add_settings_dependencies($settings)
	{
		$settings[] = include plugin_dir_path(dirname(__FILE__)) . 'admin/settings/class-eurofaktura-settings.php';
		return $settings;
	}

	/**
	 * Load dependencies for order edit page
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	public function add_order_edit_dependencies()
	{
		include_once plugin_dir_path(dirname(__FILE__)) . '/admin/order-edit/class-eurofaktura-admin-order-meta-box.php';
	}

	/**
	 * Load dependencies for orders overview page
	 *
	 * @since    1.1.0
	 * @access   private
	 */
	public function add_orders_overview_dependencies()
	{
		include_once plugin_dir_path(dirname(__FILE__)) . '/admin/orders-overview/class-eurofaktura-admin-orders-overview-bulk-actions.php';
	}

}