<?php

// If this file is called directly, abort.
if (!defined('ABSPATH')) exit;

/**
 * Displays main settings options
 *
 * @since      1.0.0
 * @package    eurofaktura
 * @subpackage eurofaktura/includes/admin/settings
 */

// Initialize options arrays
$api_keys_options = [];
$webhooks_options = [];

// Get active API credentials and webhooks
$api_keys = eurofaktura_get_active_api_credentials();
$webhooks = eurofaktura_get_active_webhooks();

// Populate API keys options
if (empty($api_keys)) {
    $api_keys_options[] = __('No API keys available.', 'eurofaktura');
} else {
    foreach ($api_keys as $key) {
        $api_keys_options[$key['key_id']] = $key['description'] . ' (ID: ' . $key['key_id'] . ')';
    }
}

// Populate webhooks options
if (empty($webhooks)) {
    $webhooks_options[] = __('No active webhooks available.', 'eurofaktura');
} else {
    foreach ($webhooks as $webhook) {
        $webhooks_options[$webhook->get_id()] = $webhook->get_name() . ' (ID: ' . $webhook->get_id() . ')';
    }
}

// Generate links
$settings_webhooks_link = '<a href="' . admin_url('admin.php?page=wc-settings&tab=advanced&section=webhooks') . '">' . __('Webhooks', 'eurofaktura') . '</a>';
$settings_api_link = '<a href="' . admin_url('admin.php?page=wc-settings&tab=advanced&section=keys') . '">' . __('REST API', 'eurofaktura') . '</a>';
$title = eurofaktura_get_title();

$setting_title_message = sprintf(
    /* translators: 1. Link text to Api key settings, 2. Title of the product, 3. Link text to webhook settings*/
    __(
        '<b>To initiate the connection, ensure you have successfully completed the following steps:</b><br>
        1. In WooCommerce under %1$s tab add a new key.<br>
        2. Add your WooCommerce online store to the %2$s ERP system.<br>
        3. Set up a webhook for your WooCommerce online store in %2$s ERP.<br>
        4. Add the %2$s webhook to your WooCommerce under the %3$s tab.<br>
        5. In the dropdowns below, select the correct API key and webhook.<br>
        6. Click on "Save Settings," and the plugin will attempt to establish a connection.

        <br><br>
        <b>Detailed guidelines</b><br>
        <a href="https://e-racuni.com/WikiDoc/p-1004D0A" target="_blank">e-računi.com Slovenia</a><br>
        <a href="https://e-racuni.hr/Croatian/p-1003DC0" target="_blank">e-računi.hr Croatia</a><br>
        <a href="https://eurofaktura.cz/HelpCZ/p-10029BA" target="_blank">eurofaktura.com Czech</a>',
        'eurofaktura'
    ),
    $settings_api_link,
    $title,
    $settings_webhooks_link
);

$setting_connection_message = '';
if (get_option("eurofaktura_connected")) {
    $setting_connection_message = sprintf(
        /* translators: 1. Color, 2. Connection info text*/
        __('<b>Connection status: <span style="color: %1$s;">%2$s</span></b><br><br>', 'eurofaktura'),
        '#00a32a',
        sprintf(
            /* translators: 1. Name of the product*/
            __('Connected to %1$s.', 'eurofaktura'),
            $title
        )
    );
} else {
    $setting_connection_message = sprintf(
        /* translators: 1. Color, 2. Connection info text*/
        __('<b>Connection status: <span style="color: %1$s;">%2$s</span></b><br><br>'),
        '#d63638',
        sprintf(
            /* translators: 1. Name of the product*/
            __('Connection to %1$s is not established.', 'eurofaktura'),
            $title
        )
    );
}
$setting_message = $setting_connection_message . $setting_title_message;


// Define settings array
$settings = [
    [
        'name' => __('Connection', 'eurofaktura'),
        'type' => 'title',
        'desc' => $setting_message,
        'id'   => 'eurofaktura_general_settings_connection',
    ],
    [
        'name'    => __('API Key', 'eurofaktura'),
        'type'    => 'select',
        'desc'    => __('Select API key', 'eurofaktura'),
        'options' => $api_keys_options,
        'id'      => 'eurofaktura_api_credentials_id',
    ],
    [
        'name'    => __('Webhook', 'eurofaktura'),
        'type'    => 'select',
        'desc'    => __('Select webhook', 'eurofaktura'),
        'options' => $webhooks_options,
        'id'      => 'eurofaktura_webhook_id',
    ],
    [
        'type' => 'sectionend',
        'desc' => 'test',
        'id'   => 'eurofaktura_general_settings_connection',
    ],
];
