<?php

// If this file is called directly, abort.
if (!defined('ABSPATH')) exit;

/**
 * Fired during plugin activation
 *
 * @since      1.0.0
 * 
 * @package    eurofaktura
 * @subpackage eurofaktura/includes
 */

class Eurofaktura_activator
{

    /**
     * Activate the plugin and attempt to connect to Eurofaktura
     *
     * @since   1.0.0
     */
    public static function activate()
    {

        // Automatically try to connect to Eurofaktura on plugin activation
        if (is_plugin_active('woocommerce/woocommerce.php')) {

            // Reset connection status and login URL on activation
            update_option('eurofaktura_connected', false);
            update_option('eurofaktura_login_url', null);

            // Get active API credentials and webhooks
            $api_credentials = eurofaktura_get_active_api_credentials();
            $webhooks = eurofaktura_get_active_webhooks();

            // Message to guide the user to the settings page
            $setting_page_message = sprintf(
                // translators: %1$s -> Link text for settings page. 
                __('Please visit %1$s page to review and set your connection information.', 'eurofaktura'),
                '<a href="' . (admin_url('admin.php?page=wc-settings&tab=eurofaktura')) . '">' .  __('settings', 'eurofaktura') . '</a>'
            );

            $notice_message = $setting_page_message;
            $notice_type = 'warning';

            // No API keys or/and Webhooks are found
            if (count($api_credentials) == 0 && count($webhooks) == 0) {
            }

            // Multiple API keys or/and Webhooks are found
            else if (count($api_credentials) > 1 || count($webhooks) > 1) {
            }

            // Only One API key and Webhook are found
            else if (count($api_credentials) == 1 && count($webhooks) == 1) {
                $key = reset($api_credentials);
                $webhook = reset($webhooks);

                update_option('eurofaktura_api_credentials_id', $key['key_id']);
                update_option('eurofaktura_webhook_id', $webhook->get_id());

                $client = Eurofaktura_http_client::instance();
                $response = $client->post_request('connection.check', null);

                if (!empty($response)) {
                    $response_status_code = $response->getStatusCode();
                    $response_body = $response->getBody()->getContents();
                    $response_body = json_decode($response_body, true);

                    $response_body_custom_status = '';
                    if (isset($response_body['status'])) {
                        $response_body_custom_status = $response_body['status'];
                    }
                    if (isset($response_body['message'])) {
                        $notice_message = $response_body['message'];
                    }

                    if ($response_status_code === 200 && $response_body_custom_status === 'connectedSuccess') {
                        update_option('eurofaktura_connected', true);
                        $notice_type = 'success';
                    } else {
                        $notice_message = $notice_message . ' ' . $setting_page_message;
                    }
                }
            }

            Eurofaktura_admin_notices::instance()->add_admin_notice($notice_message, 'eurofaktura_settings',  $notice_type);
        }
    }
}
