<?php

// If this file is called directly, abort.
if (!defined('ABSPATH')) exit;

/**
 * Eurofaktura Api functions.
 *
 * @since      1.0.0
 *
 * @package    eurofaktura
 * @subpackage eurofaktura/includes
 */

/**
 * Retrieves all active API credentials.
 *
 * @since 1.0.0
 *
 * @global wpdb $wpdb WordPress database abstraction object.
 *
 * @return array An array containing active API credentials.
 */
function eurofaktura_get_active_api_credentials()
{
    if (!eurofaktura_is_admin()) return null;

    global $wpdb;
    $data = $wpdb->get_results(
        "SELECT key_id, user_id, description, permissions, truncated_key FROM {$wpdb->prefix}woocommerce_api_keys",
        ARRAY_A
    );
    return $data;
}

/**
 * Retrieves API credentials by ID.
 *
 * @since 1.0.0
 *
 * @param int|null $api_credentials_id The ID of the API credentials to retrieve.
 *
 * @return array|null An array containing API credentials or null if not found.
 */
function eurofaktura_get_api_credentials($api_credentials_id = null)
{
    if (!eurofaktura_is_admin()) return null;
    if (0 === $api_credentials_id) return null;

    global $wpdb;
    $api_credentials = $wpdb->get_row(
        $wpdb->prepare(
            "SELECT key_id, user_id, description, permissions, truncated_key
				FROM {$wpdb->prefix}woocommerce_api_keys
				WHERE key_id = %d",
            $api_credentials_id
        ),
        ARRAY_A
    );
    if (is_null($api_credentials)) return null;
    return $api_credentials;
}

/**
 * Retrieves truncated API consumer key.
 *
 * @since 1.0.0
 *
 * @param array|null $api_credentials An array containing API credentials.
 *
 * @return string|null Truncated API consumer key or null if not provided.
 */
function eurofaktura_get_api_credentials_key($api_credentials)
{
    if (!eurofaktura_is_admin()) return null;
    if ($api_credentials === null) return null;
    return $api_credentials['truncated_key'];
}
