<?php

// If this file is called directly, abort.
if (!defined('ABSPATH')) exit;

/**
 * Eurofaktura custom logging functions
 *
 * @since      1.0.0
 *
 * @package    eurofaktura
 * @subpackage eurofaktura/includes
 */

/**
 * Adds an error log message using Eurofaktura custom logging.
 *
 * @since 1.0.0
 *
 * @param string $log_message The error log message.
 *
 * @return void
 */
function eurofaktura_add_log_error($log_message)
{
    wc_get_logger()->error($log_message, array('source' => 'eurofaktura'));
}

/**
 * Adds an info log message using Eurofaktura custom logging.
 *
 * @since 1.0.0
 *
 * @param string $log_message The info log message.
 *
 * @return void
 */
function eurofaktura_add_log_info($log_message)
{
    wc_get_logger()->info($log_message, array('source' => 'eurofaktura'));
}

/**
 * Adds a debug log message using Eurofaktura custom logging.
 * Only shows the debug log if the WP_DEBUG constant is set to true.
 *
 * @since 1.0.0
 *
 * @param string $log_message The debug log message.
 *
 * @return void
 */
function eurofaktura_add_log_debug($log_message)
{
    if (defined('WP_DEBUG') && WP_DEBUG) {
        wc_get_logger()->debug($log_message, array('source' => 'eurofaktura'));
    }
}
