<?php

// If this file is called directly, abort.
if (!defined('ABSPATH')) exit;

/**
 * Eurofaktura custom webhook functions.
 * Extended from WooCommerce/includes/wc-webhook-function.php
 *
 * @since      1.0.0
 *
 * @package    eurofaktura
 * @subpackage eurofaktura/includes
 */

/**
 * Retrieves all active webhooks.
 *
 * @since 1.0.0
 *
 * @return array An array containing all active webhooks.
 */
function eurofaktura_get_active_webhooks()
{
    if (!eurofaktura_is_admin()) return null;
    
    $active_webhooks = [];

    // Load the webhook data store
    $webhook_data_store = WC_Data_Store::load('webhook');

    // Get IDs of active webhooks
    $webhooks_ids = $webhook_data_store->get_webhooks_ids('active');

    // Fetch each active webhook by ID and add it to the array
    foreach ($webhooks_ids as $id) {
        $active_webhooks[] = wc_get_webhook($id);
    }

    return $active_webhooks;
}

/**
 * Retrieves a webhook by ID.
 *
 * @since 1.0.0
 *
 * @param int $webhook_id The ID of the webhook to retrieve.
 *
 * @return array|null An array containing the webhook data or null if not found.
 */
function eurofaktura_get_webhook($webhook_id = null)
{
    if (!eurofaktura_is_admin()) return null;
    if ($webhook_id === null) return null;
    
    return wc_get_webhook($webhook_id);
}

/**
 * Retrieves an active webhook by ID.
 *
 * @since 1.0.0
 *
 * @param int $webhook_id The ID of the webhook to retrieve.
 *
 * @return array|null An array containing the active webhook data or null if not found.
 */
function eurofaktura_get_active_webhook($webhook_id = null)
{
    if (!eurofaktura_is_admin()) return null;
    if ($webhook_id === null) return null;

    // Get the webhook by ID
    $webhook = wc_get_webhook($webhook_id);

    // Check if the webhook is active
    if ($webhook && $webhook->get_status() === 'active') return $webhook;

    return null;
}

/**
 * Retrieves the delivery URL of a webhook.
 *
 * @since 1.0.0
 *
 * @param object|null $webhook An array containing the webhook data.
 *
 * @return string|null The delivery URL of the webhook or null if not provided.
 */
function eurofaktura_get_webhook_delivery_url($webhook)
{
    if (!eurofaktura_is_admin()) return null;
    if ($webhook === null) return null;

    return $webhook->get_delivery_url();
}
