<?php

// If this file is called directly, abort.
if (!defined('ABSPATH')) exit;

/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://eurofaktura.com
 * @since      1.0.0
 *
 * @package    eurofaktura
 * @subpackage eurofaktura/includes/public/
 */

class Eurofaktura_public
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct($plugin_name, $version)
	{

		$this->plugin_name = $plugin_name;
		$this->version = $version;
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{

		/**
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Eurofaktura_loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Eurofaktura_loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/eurofaktura-public.css', array(), $this->version, 'all');
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{

		/**
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Eurofaktura_loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Eurofaktura_loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/eurofaktura-public.js', array('jquery'), $this->version, false);
	}
}
